round_digits

Function round_digits 

pub fn round_digits(number: u32, digits: u32) -> u32
round an unsigned integer to the specified amount of digits, if the integer is shorter than the number if digits, it returns the original integer