pub struct SampleInfo { /* private fields */ }Expand description
contains information about the samples required for graph construction
Example:
- Sample IDs in group 1: 0, 1, 2
- Sample IDs in group 2: 3, 4, 5, 6
use debruijn::summarizer::{SampleInfo, Marker};
let marker0: Marker = 0b0000111; // = 7
let marker1: Marker = 0b1111000; // = 120
let sample_kmers = vec![1232, 12323, 24342, 24234, 345456, 21234, 546456];
assert_eq!(marker0.count_ones() + marker1.count_ones(), sample_kmers.len() as u32);
let sample_info = SampleInfo::new(marker0, marker1, sample_kmers);
Implementations
Sourceimpl SampleInfo
impl SampleInfo
Sourcepub fn new(marker0: Marker, marker1: Marker, sample_kmers: Vec<u64>) -> Self
pub fn new(marker0: Marker, marker1: Marker, sample_kmers: Vec<u64>) -> Self
make a new SampleInfo
Arguments
marker0: a [M] which binary-encodes the affiliation of the tags to a groupmarker1: same asmarker0, for a second groupsample_kmers: aVec<u64>containing numbers of non-unique k-mers for each sample at the index of the sample-id
Sourcepub fn empty() -> Self
pub fn empty() -> Self
make a new, empty SampleInfo
Sourcepub fn get_markers(&self) -> (Marker, Marker)
pub fn get_markers(&self) -> (Marker, Marker)
get the binary encoded group affiliation of tags