pub struct TagsCountsSumData { /* private fields */ }Expand description
Implementation of SummaryData<Tag>
Contains the tags the k-mer was observed with, how many times it was observed with each label, and how many times it was observed overall