pub struct Translator { /* private fields */ }Expand description
translate tags and IDs (e.g. into sample labels and gene names)
Implementations
Sourceimpl Translator
impl Translator
Sourcepub fn new(ids: BiMap<String, ID>, tags: BiMap<String, Tag>) -> Translator
pub fn new(ids: BiMap<String, ID>, tags: BiMap<String, Tag>) -> Translator
make a new Translator for tags and IDs
Sourcepub fn empty() -> Translator
pub fn empty() -> Translator
make an empty Translator
Sourcepub fn new_tag_translator(hashed_tags: BiMap<String, Tag>) -> Translator
pub fn new_tag_translator(hashed_tags: BiMap<String, Tag>) -> Translator
make a new Translator for tags
Sourcepub fn new_id_translator(hashed_ids: BiMap<String, ID>) -> Translator
pub fn new_id_translator(hashed_ids: BiMap<String, ID>) -> Translator
make a new Translator for IDs
Sourcepub fn tag_translator(&self) -> &Option<BiMap<String, Tag>>
pub fn tag_translator(&self) -> &Option<BiMap<String, Tag>>
get the tag translator, returns None if the Translator does not contain a tag translator
Sourcepub fn id_translator(&self) -> &Option<BiMap<String, ID>>
pub fn id_translator(&self) -> &Option<BiMap<String, ID>>
get the tag translator, returns None if the Translator does not contain a tag translator
Sourcepub fn mut_id_translator(&mut self) -> &mut Option<BiMap<String, ID>>
pub fn mut_id_translator(&mut self) -> &mut Option<BiMap<String, ID>>
get a mutable reference to the tag translator, returns None if the Translator does not contain a tag translator